@@ -76,6 +76,7 @@ function load () {
   cb = once(function (er, conf) {
     if (!er)
       exports.loaded = conf
+      loading = false
     loadCbs.forEach(function (fn) {
       fn(er, conf)
     })
@@ -152,10 +153,17 @@ function load_(builtin, rc, cli, cb) {
     // annoying humans and their expectations!
     if (conf.get("prefix")) {
       var etc = path.resolve(conf.get("prefix"), "etc")
-      defaults.globalconfig = path.resolve(etc, "npmrc")
-      defaults.globalignorefile = path.resolve(etc, "npmignore")
+      mkdirp(etc, function (err) {
+        defaults.globalconfig = path.resolve(etc, "npmrc")
+        defaults.globalignorefile = path.resolve(etc, "npmignore")
+        afterUserContinuation()
+      })
+    } else {
+      afterUserContinuation()
     }
+  }
 
+  function afterUserContinuation() {
     conf.addFile(conf.get("globalconfig"), "global")
 
     // move the builtin into the conf stack now.
@@ -220,6 +228,7 @@ Conf.prototype.setUser = require("./set-user.js")
 Conf.prototype.findPrefix = require("./find-prefix.js")
 Conf.prototype.getCredentialsByURI = require("./get-credentials-by-uri.js")
 Conf.prototype.setCredentialsByURI = require("./set-credentials-by-uri.js")
+Conf.prototype.clearCredentialsByURI = require("./clear-credentials-by-uri.js")
 
 Conf.prototype.loadExtras = function(cb) {
   this.setUser(function(er) {
