@@ -36,6 +36,7 @@ var path = require("path")
   , npa = require("npm-package-arg")
   , readInstalled = require("read-installed")
   , long = npm.config.get("long")
+  , log = require("npmlog")
 
 function outdated (args, silent, cb) {
   if (typeof cb !== "function") cb = silent, silent = false
@@ -300,7 +301,10 @@ function shouldUpdate (args, dir, dep, has, req, depth, cb, type) {
   }
 
   if (args.length && args.indexOf(dep) === -1) return skip()
-  if (npa(req).type === "git") return doIt("git", "git")
+  var parsed = npa(req)
+  if (parsed.type === "git" || (parsed.hosted && parsed.hosted.type === "github")) {
+    return doIt("git", "git")
+  }
 
   // search for the latest package
   mapToRegistry(dep, npm.config, function (er, uri, auth) {
