@@ -13,30 +13,35 @@ var exec = require("child_process").execFile
   , assert = require("assert")
   , log = require("npmlog")
 
-function prefixGitArgs() {
+function prefixGitArgs () {
   return process.platform === "win32" ? ["-c", "core.longpaths=true"] : []
 }
 
-function execGit(args, options, cb) {
-  log.info("git", args)
-  return exec(git, prefixGitArgs().concat(args || []), options, cb)
+function execGit (args, options, cb) {
+  log.info('git', args)
+  var fullArgs = prefixGitArgs().concat(args || [])
+  return exec(git, fullArgs, options, function (err) {
+    if (err) log.error('git', fullArgs.join(' '))
+
+    cb.apply(null, arguments)
+  })
 }
 
-function spawnGit(args, options, cb) {
+function spawnGit (args, options) {
   log.info("git", args)
   return spawn(git, prefixGitArgs().concat(args || []), options)
 }
 
-function chainableExec() {
+function chainableExec () {
   var args = Array.prototype.slice.call(arguments)
   return [execGit].concat(args)
 }
 
-function whichGit(cb) {
+function whichGit (cb) {
   return which(git, cb)
 }
 
-function whichAndExec(args, options, cb) {
+function whichAndExec (args, options, cb) {
   assert.equal(typeof cb, "function", "no callback provided")
   // check for git
   whichGit(function (err) {
